@@ -29,7 +29,6 @@
 #include "common/SslCertificate.h"
 
 #include "MobileDialog.h"
-#include "Poller.h"
 #include "PrintSheet.h"
 #include "SettingsDialog.h"
 #include "SignatureDialog.h"
@@ -61,8 +60,6 @@ MainWindow::MainWindow( QWidget *parent )
 
 	setupUi( this );
 
-	signZipInput->setValidator( new QRegExpValidator( QRegExp( "\\d{0,5}" ), signZipInput ) );
-
 	cards->hide();
 
 	setWindowFlags( Qt::Window | Qt::CustomizeWindowHint | Qt::WindowMinimizeButtonHint );
@@ -181,7 +178,7 @@ bool MainWindow::addFile( const QString &file )
 		QString docname = QString( "%1/%2.%3" )
 			.arg( s.value( "DefaultDir", info.absolutePath() ).toString() )
 			.arg( info.fileName() )
-			.arg( s.value( "type" ,"bdoc" ).toString() );
+			.arg( s.value( "type" ,"ddoc" ).toString() );
 
 		bool select = s.value( "AskSaveAs", false ).toBool();
 		if( !select && QFile::exists( docname ) )
@@ -207,7 +204,7 @@ bool MainWindow::addFile( const QString &file )
 				return false;
 			QString ext = QFileInfo( docname ).suffix().toLower();
 			if( ext != "bdoc" || ext != "ddoc" )
-				docname.append( "." + s.value( "type" ,"bdoc" ).toString() );
+				docname.append( "." + s.value( "type" ,"ddoc" ).toString() );
 			if( !Common::canWrite( docname ) )
 			{
 				QMessageBox::warning( this, windowTitle(),
@@ -368,8 +365,8 @@ void MainWindow::buttonClicked( int button )
 		}
 		SettingsDialog::saveSignatureInfo( signRoleInput->text(),
 			signResolutionInput->text(), signCityInput->text(),
-			signStateInput->text(), signZipInput->text(),
-			signCountryInput->text() );
+			signStateInput->text(), signCountryInput->text(),
+			signZipInput->text() );
 		SettingsDialog::saveMobileInfo( infoMobileCode->text(), infoMobileCell->text() );
 		setCurrentPage( View );
 		break;
@@ -420,8 +417,18 @@ bool MainWindow::eventFilter( QObject *o, QEvent *e )
 	if( e->type() == QEvent::FileOpen )
 	{
 		QFileOpenEvent *o = static_cast<QFileOpenEvent*>(e);
-		params << o->file();
-		buttonClicked( HomeSign );
+		if( o->file().right( 4 ).toLower() == "p12d" )
+		{
+			SettingsDialog s( this );
+			s.addAction( close );
+			s.setP12Cert( o->file() );
+			s.exec();
+		}
+		else
+		{
+			params << o->file();
+			buttonClicked( HomeSign );
+		}
 		return true;
 	}
 	else
@@ -650,12 +657,17 @@ void MainWindow::setCurrentPage( Pages page, bool reload )
 			.arg( QDir::toNativeSeparators( doc->fileName() ) ) );
 		viewFileName->setToolTip( QDir::toNativeSeparators( doc->fileName() ) );
 
-		if( !signatures.isEmpty() && cardOwnerSignature )
-			viewFileStatus->setText( tr("This container is signed by you") );
-		else if( !signatures.isEmpty() && !cardOwnerSignature )
-			viewFileStatus->setText( tr("You have not signed this container") );
+		if( !doc->signCert().isNull() )
+		{
+			if( !signatures.isEmpty() && cardOwnerSignature )
+				viewFileStatus->setText( tr("This container is signed by you") );
+			else if( !signatures.isEmpty() && !cardOwnerSignature )
+				viewFileStatus->setText( tr("You have not signed this container") );
+			else
+				viewFileStatus->setText( tr("Container is unsigned") );
+		}
 		else
-			viewFileStatus->setText( tr("Container is unsigned") );
+			viewFileStatus->clear();
 
 		viewSignaturesLabel->setText( signatures.size() == 1 ? tr("Signature") : tr("Signatures") );
 
@@ -664,7 +676,7 @@ void MainWindow::setCurrentPage( Pages page, bool reload )
 		else if( test )
 			viewSignaturesError->setText( tr("NB! Test signature") );
 		else
-			viewSignaturesError->setText( QString() );
+			viewSignaturesError->clear();
 		break;
 	}
 	default: break;
@@ -673,7 +685,7 @@ void MainWindow::setCurrentPage( Pages page, bool reload )
 
 void MainWindow::showCardStatus()
 {
-	signSigner->setText( QString() );
+	signSigner->clear();
 
 	if( infoSignMobile->isChecked() )
 	{
@@ -774,16 +786,7 @@ bool MainWindow::checkAccessCert()
 		return false;
 	}
 
-	QByteArray result = doc->getAccessCert();
-	QFile f( "debug_accesscert.txt" );
-	if( f.open( QIODevice::WriteOnly|QIODevice::Truncate ) )
-	{
-		f.write( QDateTime::currentDateTime().toString().toLatin1() );
-		f.write( "\n-------------------------------\n" );
-		f.write( result );
-		f.close();
-	}
-
+	QString result = doc->getAccessCert();
 	if ( result.isEmpty() )
 	{
 		QMessageBox::warning( this, tr( "Server access certificate" ),
@@ -807,7 +810,7 @@ bool MainWindow::checkAccessCert()
 		return false;
 	}
 
-	switch( e.elementsByTagName( "ResponseStatus" ).item(0).toElement().text().toInt() )
+	switch( e.elementsByTagName( "StatusCode" ).item(0).toElement().text().toInt() )
 	{
 	case 1: //need to order cert manually from SK web
 		QDesktopServices::openUrl( QUrl( "http://www.sk.ee/toend/" ) );
