@@ -277,14 +277,14 @@ Digital signing is equal to physical signing. To sign a document you need an ID-
 Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
 Also an active internet connection is needed.&lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
 &lt;/head&gt;&lt;body&gt;
 &lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
-Dokumendi allakirjutamine.&lt;br /&gt;&lt;br /&gt;
-Digitaalallkiri on samaväärne füüsilise allkirjaga. Digitaalallkirja andmiseks on vajalik ID-kaart, millel on kehtiv ja kasutatav allkirjastamise sertifikaat.&lt;br /&gt;&lt;br /&gt;
-Dokumendi allakirjutamisel on vajalik PIN2 kood.&lt;br /&gt;&lt;br /&gt;
-Digitaalallkirja andmiseks on vajalik interneti ühendus.
+Dokumendi allkirjastamine.&lt;br /&gt;&lt;br /&gt;
+Digitaalallkiri on samaväärne füüsilise allkirjaga. Digitaalallkirja andmiseks on vajalik ID-kaart või Mobiil-ID, millel on kehtiv ja kasutatav allkirjastamise sertifikaat.&lt;br /&gt;&lt;br /&gt;
+Dokumendi allkirjastamisel on vajalik PIN2 kood.&lt;br /&gt;&lt;br /&gt;
+Digitaalallkirja andmiseks on vajalik internetiühendus.
 &lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</translation>
     </message>
@@ -381,10 +381,6 @@ Alustame laadimist?</translation>
 </context>
 <context>
     <name>MobileDialog</name>
-    <message>
-        <source>Cancel</source>
-        <translation>Katkesta</translation>
-    </message>
     <message>
         <source>Signing in process</source>
         <translation>Toimub allkirjastamine</translation>
@@ -434,8 +430,8 @@ Alustame laadimist?</translation>
         <translation>Allkirjastan Mobiil-ID -ga</translation>
     </message>
     <message>
-        <source>Control code</source>
-        <translation>Kontrollkood</translation>
+        <source>Control code: %1</source>
+        <translation>Kontrollkood: %1</translation>
     </message>
     <message>
         <source>%v sec</source>
@@ -453,13 +449,6 @@ Palun kontrollige internetiühendust.</translation>
         <translation>Kasutaja ei ole Mobiil-ID klient</translation>
     </message>
 </context>
-<context>
-    <name>Poller</name>
-    <message>
-        <source>Failed to load PKCS#11 module</source>
-        <translation>PKCS#11 mooduli laadimine ebaõnnestus</translation>
-    </message>
-</context>
 <context>
     <name>PrintSheet</name>
     <message>
@@ -560,14 +549,38 @@ Palun kontrollige internetiühendust.</translation>
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>QSigner</name>
+    <message>
+        <source>Failed to load PKCS#11 module</source>
+        <translation>PKCS#11 mooduli laadimine ebaõnnestus</translation>
+    </message>
     <message>
         <source>PIN acquisition canceled.</source>
         <translation>PIN koodi sisestamine katkestati.</translation>
     </message>
     <message>
-        <source>Could not find sign certificate.</source>
-        <translation>Ei leidnud allkirjastamise sertifikaati.</translation>
+        <source>Signing certificate is not selected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to login token</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIN Incorrect</source>
+        <translation>PIN vigane</translation>
+    </message>
+    <message>
+        <source>PIN Locked</source>
+        <translation>PIN on lukus</translation>
+    </message>
+    <message>
+        <source>Failed to login to token &apos;%1&apos;: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to sign document</source>
+        <translation>Dokumendi allkirjastamine ebaõnnestus</translation>
     </message>
 </context>
 <context>
@@ -596,10 +609,6 @@ Palun kontrollige internetiühendust.</translation>
         <source>OCSP PKCS#12 certificate</source>
         <translation>Ligipääsutõend</translation>
     </message>
-    <message>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
     <message>
         <source>Password</source>
         <translation>Parool</translation>
@@ -645,10 +654,6 @@ Palun kontrollige internetiühendust.</translation>
         <source>Zip</source>
         <translation>Indeks</translation>
     </message>
-    <message>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
     <message>
         <source>Select folder</source>
         <translation>Vali kataloog</translation>
@@ -717,6 +722,10 @@ Palun kontrollige internetiühendust.</translation>
         <source>Username</source>
         <translation>Kasutajanimi</translation>
     </message>
+    <message>
+        <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SignatureDialog</name>
@@ -812,26 +821,18 @@ Palun kontrollige internetiühendust.</translation>
         <source>Unknown error</source>
         <translation>Tundmatu viga</translation>
     </message>
-    <message>
-        <source>Type</source>
-        <translation>Tüüp</translation>
-    </message>
     <message>
         <source>Time</source>
         <translation>Aeg</translation>
     </message>
-    <message>
-        <source>SHA1 hash</source>
-        <translation>SHA1 räsi</translation>
-    </message>
-    <message>
-        <source>Subject name</source>
-        <translation>Pealkirja nimi</translation>
-    </message>
     <message>
         <source>Signature status unknown (%1)</source>
         <translation>Allkirja staatus on teadmata (%1)</translation>
     </message>
+    <message>
+        <source>Hash value of validity confirmation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SignatureWidget</name>
