@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
 <context>
     <name>DigiDoc</name>
     <message>
@@ -270,7 +270,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt;</source>
-        <translation>&lt;a href=&quot;addFile&quot;&gt;Добавить файлl&lt;/a&gt;</translation>
+        <translation>&lt;a href=&quot;addFile&quot;&gt;Добавить файл&lt;/a&gt;</translation>
     </message>
     <message>
         <source>This container is </source>
@@ -278,7 +278,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;</source>
-        <translation>&lt;a href=&quot;email&quot;&gt;Отослать контейнет по эл. почте&lt;/a&gt;</translation>
+        <translation>&lt;a href=&quot;email&quot;&gt;Отослать контейнер по эл. почте&lt;/a&gt;</translation>
     </message>
     <message>
         <source>&lt;a href=&quot;print&quot;&gt;Print summary&lt;/a&gt;</source>
@@ -381,10 +381,6 @@ Start downloading?</source>
 </context>
 <context>
     <name>MobileDialog</name>
-    <message>
-        <source>Cancel</source>
-        <translation>Прервать</translation>
-    </message>
     <message>
         <source>Signing in process</source>
         <translation>Подписывание</translation>
@@ -434,8 +430,8 @@ Start downloading?</source>
         <translation>Подписывается с Mobiil-ID</translation>
     </message>
     <message>
-        <source>Control code</source>
-        <translation>Контрольный код</translation>
+        <source>Control code: %1</source>
+        <translation>Контрольный код: %1</translation>
     </message>
     <message>
         <source>%v sec</source>
@@ -452,13 +448,6 @@ Please check your internet connection.</source>
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>Poller</name>
-    <message>
-        <source>Failed to load PKCS#11 module</source>
-        <translation>Неудачная загрузка модуля PKCS#11</translation>
-    </message>
-</context>
 <context>
     <name>PrintSheet</name>
     <message>
@@ -559,14 +548,38 @@ Please check your internet connection.</source>
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>QSigner</name>
+    <message>
+        <source>Failed to load PKCS#11 module</source>
+        <translation>Неудачная загрузка модуля PKCS#11</translation>
+    </message>
     <message>
         <source>PIN acquisition canceled.</source>
         <translation>Введение PIN кода было прервано.</translation>
     </message>
     <message>
-        <source>Could not find sign certificate.</source>
-        <translation>Сертификат подписи не найден.</translation>
+        <source>Signing certificate is not selected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to login token</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIN Incorrect</source>
+        <translation>Неверный PIN</translation>
+    </message>
+    <message>
+        <source>PIN Locked</source>
+        <translation>PIN заблокирован</translation>
+    </message>
+    <message>
+        <source>Failed to login to token &apos;%1&apos;: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to sign document</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -595,10 +608,6 @@ Please check your internet connection.</source>
         <source>OCSP PKCS#12 certificate</source>
         <translation>Сертификат доступа</translation>
     </message>
-    <message>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
     <message>
         <source>Password</source>
         <translation>Пароль</translation>
@@ -628,10 +637,6 @@ Please check your internet connection.</source>
         <source>Same folder</source>
         <translation>Та же папка</translation>
     </message>
-    <message>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
     <message>
         <source>Ask container name</source>
         <translation>Спросить название контейнера</translation>
@@ -716,6 +721,10 @@ Please check your internet connection.</source>
         <source>Username</source>
         <translation>Имя пользователя</translation>
     </message>
+    <message>
+        <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SignatureDialog</name>
@@ -811,26 +820,18 @@ Please check your internet connection.</source>
         <source>Verify</source>
         <translation>Подтвердить</translation>
     </message>
-    <message>
-        <source>Type</source>
-        <translation>Тип</translation>
-    </message>
     <message>
         <source>Time</source>
         <translation>Время</translation>
     </message>
-    <message>
-        <source>SHA1 hash</source>
-        <translation>SHA1 хэш</translation>
-    </message>
-    <message>
-        <source>Subject name</source>
-        <translation>Название заглавия</translation>
-    </message>
     <message>
         <source>Signature status unknown (%1)</source>
         <translation>Неизвестный статус пользователя (%1)</translation>
     </message>
+    <message>
+        <source>Hash value of validity confirmation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SignatureWidget</name>
